nxp-pac

Crates

git

Versions

mcxa577

Flavors

SgiStatus

Struct SgiStatus 

#[repr(transparent)]
pub struct SgiStatus(pub u32);
Status register

Tuple Fields

0: u32

Implementations

Source

impl SgiStatus

pub const fn busy(&self) -> bool

Combined busy flag that remains high until end of calculation

pub const fn set_busy(&mut self, val: bool)

Combined busy flag that remains high until end of calculation

pub const fn oflow(&self) -> bool

Overflow in INCR operation flag

pub const fn set_oflow(&mut self, val: bool)

Overflow in INCR operation flag

pub const fn prng_rdy(&self) -> bool

Indicates if PRNG is ready after boot-up phase

pub const fn set_prng_rdy(&mut self, val: bool)

Indicates if PRNG is ready after boot-up phase

pub const fn error(&self) -> Error

Error detected

pub const fn set_error(&mut self, val: Error)

Error detected

pub const fn sha2_busy(&self) -> bool

Indicates if SHA2 kernal is busy

pub const fn set_sha2_busy(&mut self, val: bool)

Indicates if SHA2 kernal is busy

pub const fn irq(&self) -> bool

Interrupt status bit

pub const fn set_irq(&mut self, val: bool)

Interrupt status bit

pub const fn sha_fifo_full(&self) -> bool

Indicates if SHA FIFO is full

pub const fn set_sha_fifo_full(&mut self, val: bool)

Indicates if SHA FIFO is full

pub const fn sha_fifo_level(&self) -> u8

SHA FIFO level (0x00 indicates empty, and 0x1F indicates full)

pub const fn set_sha_fifo_level(&mut self, val: u8)

SHA FIFO level (0x00 indicates empty, and 0x1F indicates full)

pub const fn sha_error(&self) -> bool

SHA error (see SHA errors for details)

pub const fn set_sha_error(&mut self, val: bool)

SHA error (see SHA errors for details)

pub const fn key_read_err(&self) -> bool

KEY SFR READ ERROR, sticky, cleared only with reset or flush

pub const fn set_key_read_err(&mut self, val: bool)

KEY SFR READ ERROR, sticky, cleared only with reset or flush

pub const fn key_unwrap_err(&self) -> bool

KEY UNWRAP ERROR , sticky, cleared only with reset or flush

pub const fn set_key_unwrap_err(&mut self, val: bool)

KEY UNWRAP ERROR , sticky, cleared only with reset or flush